==> jc-1.4.0.tar.gz: java/io/OptionalDataException.h <==
// public class java.io.OptionalDataException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class 3833b61d75b9be5b java_io_OptionalDataException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_OptionalDataException_H_
#define _JC_java_io_OptionalDataException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_OptionalDataException$sub_refs	_jc_java_io_OptionalDataException$sub_refs;
typedef struct _jc_java_io_OptionalDataException$sub_nonrefs	_jc_java_io_OptionalDataException$sub_nonrefs;
typedef struct _jc_java_io_OptionalDataException$refs	_jc_java_io_OptionalDataException$refs;
typedef struct _jc_java_io_OptionalDataException$nonrefs	_jc_java_io_OptionalDataException$nonrefs;
typedef struct _jc_java_io_OptionalDataException$object	_jc_java_io_OptionalDataException$object;

typedef struct _jc_java_io_OptionalDataException$fields_struct	_jc_java_io_OptionalDataException$fields_struct;
typedef const struct _jc_java_io_OptionalDataException$vmethods	_jc_java_io_OptionalDataException$vmethods;
typedef const struct _jc_java_io_OptionalDataException$vtable	_jc_java_io_OptionalDataException$vtable;
typedef const struct _jc_java_io_OptionalDataException$vtype	_jc_java_io_OptionalDataException$vtype;

// Class fields structure
struct _jc_java_io_OptionalDataException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_OptionalDataException$fields_struct _jc_java_io_OptionalDataException$class_fields;

// Constructors
extern void _jc_java_io_OptionalDataException$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_java_io_OptionalDataException$object *, jboolean, jint);

// Virtual methods structure
struct _jc_java_io_OptionalDataException$vmethods {
};

// Vtable
struct _jc_java_io_OptionalDataException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_OptionalDataException$vmethods	java_io_OptionalDataException;
};

// Vtype
struct _jc_java_io_OptionalDataException$vtype {
	_jc_type			type;
	_jc_java_io_OptionalDataException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_OptionalDataException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_OptionalDataException$refs {
    _jc_java_io_OptionalDataException$sub_refs	java_io_OptionalDataException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_OptionalDataException$sub_nonrefs {
	jboolean	eof;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_java_io_OptionalDataException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_OptionalDataException$sub_nonrefs	java_io_OptionalDataException;
};

// Object instance structure
struct _jc_java_io_OptionalDataException$object {
	_jc_java_io_OptionalDataException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_OptionalDataException$vtype	*vtype;
	_jc_java_io_OptionalDataException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_OptionalDataException$vtype _jc_java_io_OptionalDataException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_OptionalDataException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_OptionalDataException$class_object;

#endif	/* _JC_java_io_OptionalDataException_H_ */

==> jc-1.4.6.tar.gz: java/io/OptionalDataException.h <==
// public class java.io.OptionalDataException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class 3833b61d75b9be5b java_io_OptionalDataException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_OptionalDataException_H_
#define _JC_java_io_OptionalDataException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_io_OptionalDataException$sub_refs	_jc_java_io_OptionalDataException$sub_refs;
typedef struct _jc_java_io_OptionalDataException$sub_nonrefs	_jc_java_io_OptionalDataException$sub_nonrefs;
typedef struct _jc_java_io_OptionalDataException$refs	_jc_java_io_OptionalDataException$refs;
typedef struct _jc_java_io_OptionalDataException$nonrefs	_jc_java_io_OptionalDataException$nonrefs;
typedef struct _jc_java_io_OptionalDataException$object	_jc_java_io_OptionalDataException$object;

typedef struct _jc_java_io_OptionalDataException$fields_struct	_jc_java_io_OptionalDataException$fields_struct;
typedef const struct _jc_java_io_OptionalDataException$vmethods	_jc_java_io_OptionalDataException$vmethods;
typedef const struct _jc_java_io_OptionalDataException$vtable	_jc_java_io_OptionalDataException$vtable;
typedef const struct _jc_java_io_OptionalDataException$vtype	_jc_java_io_OptionalDataException$vtype;

// Class fields structure
struct _jc_java_io_OptionalDataException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_OptionalDataException$fields_struct _jc_java_io_OptionalDataException$class_fields;

// Constructors
extern void _jc_java_io_OptionalDataException$method$_init$9ff456f5359e4cdd(_jc_env *, struct _jc_java_io_OptionalDataException$object *, jboolean, jint) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_io_OptionalDataException$vmethods {
};

// Vtable
struct _jc_java_io_OptionalDataException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_OptionalDataException$vmethods	java_io_OptionalDataException;
};

// Vtype
struct _jc_java_io_OptionalDataException$vtype {
	_jc_type			type;
	_jc_java_io_OptionalDataException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_OptionalDataException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_io_OptionalDataException$refs {
    _jc_java_io_OptionalDataException$sub_refs	java_io_OptionalDataException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_OptionalDataException$sub_nonrefs {
	jboolean	eof;
	jint	length;
};

// Non-reference instance fields (object)
struct _jc_java_io_OptionalDataException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_OptionalDataException$sub_nonrefs	java_io_OptionalDataException;
};

// Object instance structure
struct _jc_java_io_OptionalDataException$object {
	_jc_java_io_OptionalDataException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_OptionalDataException$vtype	*vtype;
	_jc_java_io_OptionalDataException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_OptionalDataException$vtype _jc_java_io_OptionalDataException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_OptionalDataException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_OptionalDataException$class_object;

#endif	/* _JC_java_io_OptionalDataException_H_ */
